==> marine-runtime-v0.32.2.tar.gz: marine/crates/wasm-backend-traits/src/store.rs <==
/*
 * Copyright 2023 Fluence Labs Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

use crate::WasmBackend;

/// `Store` is an object that stores modules, instances, functions memories and so on.
/// `Store` is grow-only: once something added, it will not be removed until Store is destroyed.
/// Some of the implementations can limit allocated resources.
/// For example, Wasmtime cannot have more than 10000 instances in one `Store`.
///
/// Most of the functions in this crate require a handle to `Store` to work.
pub trait Store<WB: WasmBackend>: AsContextMut<WB> {
    fn new(backend: &WB) -> Self;

    // TODO: create general/backend-specific core config when new parameters are needed
    fn set_total_memory_limit(&mut self, total_memory_limit: u64);

    fn report_memory_allocation_stats(&self) -> Option<MemoryAllocationStats>;

    fn clear_allocation_stats(&mut self);
}

/// A temporary immutable handle to store
pub trait Context<WB: WasmBackend>: AsContext<WB> {}

/// A temporary mutable handle to store
pub trait ContextMut<WB: WasmBackend>: AsContextMut<WB> {}

pub trait AsContext<WB: WasmBackend> {
    fn as_context(&self) -> <WB as WasmBackend>::Context<'_>;
}

pub trait AsContextMut<WB: WasmBackend>: AsContext<WB> {
    fn as_context_mut(&mut self) -> <WB as WasmBackend>::ContextMut<'_>;
}

#[derive(Default, Clone, Debug)]
pub struct MemoryAllocationStats {
    pub allocation_rejects: u32,
}

==> marine-runtime-v0.37.0.tar.gz: marine/crates/wasm-backend-traits/src/store.rs <==
/*
 * Copyright 2023 Fluence Labs Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

use crate::WasmBackend;

/// `Store` is an object that stores modules, instances, functions memories and so on.
/// `Store` is grow-only: once something added, it will not be removed until Store is destroyed.
/// Some of the implementations can limit allocated resources.
/// For example, Wasmtime cannot have more than 10000 instances in one `Store`.
///
/// Most of the functions in this crate require a handle to `Store` to work.
pub trait Store<WB: WasmBackend>: AsContextMut<WB> {
    fn new(backend: &WB) -> Self;

    // TODO: create general/backend-specific core config when new parameters are needed
    fn set_total_memory_limit(&mut self, total_memory_limit: u64);

    fn report_memory_allocation_stats(&self) -> Option<MemoryAllocationStats>;

    fn clear_allocation_stats(&mut self);
}

/// A temporary immutable handle to store
pub trait Context<WB: WasmBackend>: AsContext<WB> + Send {}

/// A temporary mutable handle to store
pub trait ContextMut<WB: WasmBackend>: AsContextMut<WB> + Send {}

pub trait AsContext<WB: WasmBackend>: Send {
    fn as_context(&self) -> <WB as WasmBackend>::Context<'_>;
}

pub trait AsContextMut<WB: WasmBackend>: AsContext<WB> {
    fn as_context_mut(&mut self) -> <WB as WasmBackend>::ContextMut<'_>;
}

#[derive(Default, Clone, Debug)]
pub struct MemoryAllocationStats {
    pub allocation_rejects: u32,
}
